==> school_algorithms-1.11.1.tar.gz: school_algorithms-1.11.1/README.md <==
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]



### Table of Contents
1. About The Project
2. Algorithms
3. How to Install
4. How to update to latest version
5. How to Import

# **School Algorithms**
  ***school_algorithms is a Python module for secondary school maths and physics equations.
  It aims to provide a simple way for secondary school students
  to learn and calculate equations that they often use.***

### Functions include:
- _A function that calculates power from energy and time_
- _A function that calculates energy from power and time_
- _A function that calculates time from power and energy_
- _A function that uses Pythagorean theorem to calculate the hypotenuse of a right-angled triangle_
- _A function that uses Pythagorean theorem to calculate a leg of a right-angled triangle_
- _A function that calculates the area of a triangle_
- _A function that calculates the area of a trapezium_
- _A function that calculates the area of a circle_
- _A function that calculates the volume of a right rectangle pyramid_
- _A function that calculates the circumference of a circle_
- _A function that calculates the circumference of a circle using diameter_
- _A function that calculates the volume of a square based pyramid_
- _A function that calculates the Lowest Common Multiple from 3 numbers_
- _A function that calculates the area of a sector in a circle_

### To install:
```
python3 -m pip install school_algorithms
```
### To update to latest version:
```
python3 -m pip --upgrade school_algorithms
```
### To import:
```
import school_algorithms
```





[contributors-shield]: https://img.shields.io/github/contributors/Sammygarch/school_algorithms.svg?style=for-the-badge
[contributors-url]: https://github.com/Sammygarch/school_algorithms/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/Sammygarch/school_algorithms.svg?style=for-the-badge
[forks-url]: https://github.com/Sammygarch/school_algorithms/network/members
[stars-shield]: https://img.shields.io/github/stars/Sammygarch/school_algorithms.svg?style=for-the-badge
[stars-url]: https://github.com/Sammygarch/school_algorithms/stargazers
[issues-shield]: https://img.shields.io/github/issues/Sammygarch/school_algorithms.svg?style=for-the-badge
[issues-url]: https://github.com/Sammygarch/school_algorithms/issues
[license-shield]: https://img.shields.io/github/license/Sammygarch/school_algorithms.svg?style=for-the-badge
[license-url]: https://github.com/Sammygarch/school_algorithms/blob/master/LICENSE.txt

==> school_algorithms-1.12.0.tar.gz: school_algorithms-1.12.0/README.md <==
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]



### Table of Contents
> About The Project

> Algorithms

> How to Install

> How to update to latest version

> How to Import

# **School Algorithms**
  ***school_algorithms is a Python module for secondary school maths and physics equations.
  It aims to provide a simple way for secondary school students
  to learn and calculate equations that they often use.***

### Functions include:
- _A function that calculates power from energy and time_
- _A function that calculates energy from power and time_
- _A function that calculates time from power and energy_
- _A function that uses Pythagorean theorem to calculate the hypotenuse of a right-angled triangle_
- _A function that uses Pythagorean theorem to calculate a leg of a right-angled triangle_
- _A function that calculates the area of a triangle_
- _A function that calculates the area of a trapezium_
- _A function that calculates the volume of a right rectangle pyramid_
- _A function that calculates the area of a circle_
- _A function that calculates the circumference of a circle_
- _A function that calculates the circumference of a circle using diameter_
- _A function that calculates the area of a sector in a circle_
- _A function that calculates the volume of a square based pyramid_
- _A function that calculates the Lowest Common Multiple from 2 numbers_
- _A function that calculates the Lowest Common Multiple from 3 numbers_
- _A function that calculates the Lowest Common Multiple from 4 numbers_


### To install:
```
python3 -m pip install school_algorithms
```
### To update to latest version:
```
python3 -m pip --upgrade school_algorithms
```
### To import:
```
import school_algorithms
```





[contributors-shield]: https://img.shields.io/github/contributors/Sammygarch/school_algorithms.svg?style=for-the-badge
[contributors-url]: https://github.com/Sammygarch/school_algorithms/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/Sammygarch/school_algorithms.svg?style=for-the-badge
[forks-url]: https://github.com/Sammygarch/school_algorithms/network/members
[stars-shield]: https://img.shields.io/github/stars/Sammygarch/school_algorithms.svg?style=for-the-badge
[stars-url]: https://github.com/Sammygarch/school_algorithms/stargazers
[issues-shield]: https://img.shields.io/github/issues/Sammygarch/school_algorithms.svg?style=for-the-badge
[issues-url]: https://github.com/Sammygarch/school_algorithms/issues
[license-shield]: https://img.shields.io/github/license/Sammygarch/school_algorithms.svg?style=for-the-badge
[license-url]: https://github.com/Sammygarch/school_algorithms/blob/master/LICENSE.txt
